@@ -64,16 +64,21 @@ class BinanceHandler:
         })
 
     def lending_interest_history(self, begin_time, end_time, asset):
-        """查询利息"""
+        """查询活期利息"""
         parameters = {
             "lendingType": "DAILY",
             "startTime": begin_time,
             "endTime": end_time,
             "asset": asset,
+            "size": 100,
             "timestamp": int(datetime.now().timestamp() * 1000)
         }
         return self.__ccxt_provider.ccxt_object_for_query.sapiGetLendingUnionInterestHistory(parameters)
 
+    def all_premium(self, parameters={}):
+        """所有合约溢价信息"""
+        return self.__ccxt_provider.ccxt_object_for_query.dapiPublicGetPremiumIndex(parameters)
+
     def fetch_balance(self, type="spot"):
         """查询余额
         type: spot/margin/future"""
